from setuptools import setup

setup(
    name='marius',
    packages=['marius.core', 'marius.helper'],
    version='0.1.0',
    description='Light weight job scheduling tool with more performance and scalability.',
    url='https://github.com/Jack-Kingdom/marius.git',
    license='MIT',
    author='Jack King',
    author_email='email@qiaohong.org',
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Natural Language :: English',
    ],
)
